summaryrefslogtreecommitdiff
path: root/bootloader/ota-dfu-python
diff options
context:
space:
mode:
authorluz paz <luzpaz@github.com>2022-05-31 15:17:36 -0400
committerRiku Isokoski <riksu9000@gmail.com>2022-06-05 09:31:23 +0300
commit03a510bd182cdb89005d75e0f8dacf734efce315 (patch)
tree581d6638c06a2211c2d154e69cf66d702e1de818 /bootloader/ota-dfu-python
parent7f45538eb53235ab4015fcf13533796c8759c7bc (diff)
Fix various typos
Found via `codespell -q 3 -S ./src/libs -L ans,doubleclick,trough`
Diffstat (limited to 'bootloader/ota-dfu-python')
-rw-r--r--bootloader/ota-dfu-python/ble_secure_dfu_controller.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bootloader/ota-dfu-python/ble_secure_dfu_controller.py b/bootloader/ota-dfu-python/ble_secure_dfu_controller.py
index 7065458a..c2038ebd 100644
--- a/bootloader/ota-dfu-python/ble_secure_dfu_controller.py
+++ b/bootloader/ota-dfu-python/ble_secure_dfu_controller.py
@@ -236,7 +236,7 @@ class BleDfuControllerSecure(NrfBleDfuController):
self._dfu_send_command(Procedures.EXECUTE)
self._wait_and_parse_notify()
- print("Init packet successfully transfered")
+ print("Init packet successfully transferred")
# --------------------------------------------------------------------------
# Send the Firmware image to peripheral device.
@@ -319,5 +319,5 @@ class BleDfuControllerSecure(NrfBleDfuController):
self._dfu_send_command(Procedures.EXECUTE)
self._wait_and_parse_notify()
# If everything executed correctly, return amount of bytes transfered
return obj_max_size
@@ -319,5 +319,5 @@ class BleDfuControllerSecure(NrfBleDfuController):
self._dfu_send_command(Procedures.EXECUTE)
self._wait_and_parse_notify()
- # If everything executed correctly, return amount of bytes transfered
+ # If everything executed correctly, return amount of bytes transferred
return obj_max_size